# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-09-14 16:01
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('notifications', '0002_auto_20160527_1624'),
    ]

    operations = [
        migrations.CreateModel(
            name='EventsSubscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('last_datetime_updated', models.DateTimeField(auto_now=True)),
                ('user', models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='eventssubscriptions', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AlterField(
            model_name='billactionsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='billactionsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='billsearchsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='billsearchsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='committeeactionsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='committeeactionsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='committeeeventsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='committeeeventsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='personsubscription',
            name='user',
            field=models.ForeignKey(db_column='user_id', on_delete=django.db.models.deletion.CASCADE, related_name='personsubscriptions', to=settings.AUTH_USER_MODEL),
        ),
    ]
